@@ -75,7 +75,8 @@ using namespace std;
 
 namespace libdar
 {
-    static void libdar_init(bool init_libgcrypt_if_not_done); // drives the "libdar_initialized" variable
+    static void libdar_init(bool init_libgcrypt_if_not_done, // drives the "libdar_initialized" variable
+			    bool init_gpgme); // whether to initialize gpgme
 
     static bool libdar_initialized = false; //< static variable modified once during the first get_version call
 #ifdef CRYPTO_AVAILABLE
@@ -88,7 +89,7 @@ namespace libdar
 	NLS_SWAP_IN;
         major = LIBDAR_COMPILE_TIME_MAJOR;
         minor = LIBDAR_COMPILE_TIME_MINOR;
-	libdar_init(init_libgcrypt);
+	libdar_init(init_libgcrypt, true);
 	NLS_SWAP_OUT;
     }
 
@@ -105,11 +106,22 @@ namespace libdar
         major = LIBDAR_COMPILE_TIME_MAJOR;
 	medium = LIBDAR_COMPILE_TIME_MEDIUM;
         minor = LIBDAR_COMPILE_TIME_MINOR;
-	libdar_init(init_libgcrypt);
+	libdar_init(init_libgcrypt, true);
 	NLS_SWAP_OUT;
     }
 
-    static void libdar_init(bool init_libgcrypt_if_not_done)
+    void get_version(U_I & major, U_I & medium, U_I & minor, bool init_libgcrypt, bool init_gpgme)
+    {
+	NLS_SWAP_IN;
+
+        major = LIBDAR_COMPILE_TIME_MAJOR;
+	medium = LIBDAR_COMPILE_TIME_MEDIUM;
+        minor = LIBDAR_COMPILE_TIME_MINOR;
+	libdar_init(init_libgcrypt, init_gpgme);
+	NLS_SWAP_OUT;
+    }
+
+    static void libdar_init(bool init_libgcrypt_if_not_done, bool init_gpgme)
     {
 	if(!libdar_initialized)
 	{
@@ -174,14 +186,17 @@ namespace libdar
 	    // initializing gpgme
 
 #if GPGME_SUPPORT
-	    if(gpgme_check_version(GPGME_MIN_VERSION) == nullptr)
+	    if(init_gpgme)
 	    {
-		string tmp = "GPGME_SUPPORT";
-		throw Erange("libdar_init_gpgme", tools_printf(gettext("GPGME version requirement is not satisfied, requires version > %s"), tmp.c_str()));
-	    }
+		if(gpgme_check_version(GPGME_MIN_VERSION) == nullptr)
+		{
+		    string tmp = "GPGME_SUPPORT";
+		    throw Erange("libdar_init_gpgme", tools_printf(gettext("GPGME version requirement is not satisfied, requires version > %s"), tmp.c_str()));
+		}
 
-	    if(gpgme_err_code(gpgme_engine_check_version(GPGME_PROTOCOL_OpenPGP)) != GPG_ERR_NO_ERROR)
-		throw Erange("libdar_init_gpgme", tools_printf(gettext("GPGME engine not available: %s"), gpgme_get_protocol_name(GPGME_PROTOCOL_OpenPGP)));
+		if(gpgme_err_code(gpgme_engine_check_version(GPGME_PROTOCOL_OpenPGP)) != GPG_ERR_NO_ERROR)
+		    throw Erange("libdar_init_gpgme", tools_printf(gettext("GPGME engine not available: %s"), gpgme_get_protocol_name(GPGME_PROTOCOL_OpenPGP)));
+	    }
 #endif
 	    // initializing libcurl
 
